# { weight, force, gravitational force? }

description "weight" https://www.nist.gov/pml/owm/approximate-conversions-us-customary-measures-metric US customary units: lbf, pound of force: https://en.wikipedia.org/wiki/Pound_(force) { standard acceleration due to gravity } = (32.174049 feet) / (seconds ^ 2) 1 lbf = (1 POUND * 32.174049 feet) / (seconds ^ 2) conversion: 1 pound of force = 4.448222 Newtons (1 pound * 32.174049 feet) / (seconds ^ 2) = (.45 kilograms * 9.80665 meters) / (seconds ^ 2) poundal: poundal = (1 pound * 1 foot) / (seconds ^ 2) slug: relevant: pound of mass: https://en.wikipedia.org/wiki/Pound_(mass) System International: Newtons: 1 Newton = (1 Kilogram * Meters) / (seconds ^ 2) examples: (50 kg) * (9.90665 meters / seconds ** 2) ~= 495.3325 Newton